@@ -31,6 +31,9 @@ import zc.buildout
 from jinja2 import Template, StrictUndefined
 from contextlib import contextmanager
 
+_buildout_safe_dumps = getattr(zc.buildout.buildout, 'dumps', None)
+DUMPS_KEY = 'dumps'
+
 @contextmanager
 def umask(mask):
     original = os.umask(mask)
@@ -70,6 +73,8 @@ class Recipe(object):
         self.rendered = options['rendered']
         self.extension_list = [x for x in (y.strip() for y in options.get('extensions', '').split()) if x]
         self.context = context = {}
+        if _buildout_safe_dumps is not None:
+            context[DUMPS_KEY] = _buildout_safe_dumps
         for line in options.get('context').splitlines(False):
             if not line:
                 continue
